==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/igr-polar-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrPolarLineSeriesBase } from "./igr-polar-line-series-base";
import { PolarLineSeries } from "./PolarLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent polar line series.
*/
var IgrPolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrPolarLineSeries, _super);
    function IgrPolarLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrPolarLineSeries.prototype.createImplementation = function () {
        return new PolarLineSeries();
    };
    Object.defineProperty(IgrPolarLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.acm;
        },
        set: function (v) {
            this.i.acm = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrPolarLineSeries;
}(IgrPolarLineSeriesBase));
export { IgrPolarLineSeries };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/igr-polar-line-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrPolarLineSeriesBase } from "./igr-polar-line-series-base";
import { PolarLineSeries } from "./PolarLineSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent polar line series.
*/
var IgrPolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrPolarLineSeries, _super);
    function IgrPolarLineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrPolarLineSeries.prototype.createImplementation = function () {
        return new PolarLineSeries();
    };
    Object.defineProperty(IgrPolarLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarLineSeries.prototype, "isLineOnly", {
        /**
         * Gets whether the current series shows only line shapes.
        */
        get: function () {
            return this.i.fk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPolarLineSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.acv;
        },
        set: function (v) {
            this.i.acv = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrPolarLineSeries;
}(IgrPolarLineSeriesBase));
export { IgrPolarLineSeries };
